@@ -14,7 +14,7 @@ class Lexer:
         (r'\n', TokenType.NEW_LINE),
         (r'\s', TokenType.SPACE),
         (r'\b(if|elif|else|switch|case|while|for|break|continue)\b', TokenType.RESERVED),
-        (r'\b(echo|read|var|const|func|return|import|from)\b', TokenType.RESERVED),
+        (r'\b(echo|read|var|let|func|return|import|from)\b', TokenType.RESERVED),
         (r'\b(class|init|super|this|abstract|interface|of)\b', TokenType.RESERVED),
         (r'\b(try|catch|null|with)\b', TokenType.RESERVED),
         (r'[\(\)\{\}\[\];,]', TokenType.RESERVED),
